@@ -2,21 +2,20 @@
 //  "includes" and global variable definitions for class Clmbr
 
 
-#if !defined  CLMBR_G_H__		//prevents compiler from repeating this code in other files
+#if !defined  CLMBR_G_H__		// prevents compiler from repeating this code in other files
 #define  CLMBR_G_H__
 
 
-#define R_NO_REMAP
-
-#include <iomanip>
-#include <algorithm>
-#include <limits>
-#include <math.h>
+#include <iomanip>				// for 'setw'
+#include <algorithm>			// for 'min', 'max'
+#include <math.h>				// for 'sqrt', 'log', 'cos' 
 #include <time.h>
 
+extern "C" {
 #include <R.h>
-#include <R_ext/Applic.h>		//  for 'Rdqags' and 'Rdqagi'
+#include <R_ext/Applic.h>		// for 'Rdqags' and 'Rdqagi'
 #include <R_ext/Lapack.h>
+}
 
 #include <Rcpp.h>
 
@@ -32,18 +31,19 @@
 
 
 using TNT::Vector;
-using std::endl;
 using Rcpp::NumericVector;
 using Rcpp::NumericMatrix;
-using Rcpp::Rcout;
 using Rcpp::stop;
+using Rcpp::Rcout;
+using std::endl;
 
 
 enum  MODEL { M1, M2, M3 };
 enum  METHOD { GEO, GEO2, AF, AF2, MC, INIT };
 const double zero_eq = ldexp( 1., -40 );
-const double Inf = numeric_limits<double>::infinity();     
-const double NaN = numeric_limits<double>::quiet_NaN();
+const double Inf = R_PosInf;
+const double NaN = R_NaN;
+const double pi = M_PI;
 
 
 #endif
